@@ -1,6 +1,7 @@
 """ Module defining constants """
 
 # string constants for processor names
+LANGID = 'langid'
 TOKENIZE = 'tokenize'
 MWT = 'mwt'
 POS = 'pos'
@@ -8,3 +9,4 @@ LEMMA = 'lemma'
 DEPPARSE = 'depparse'
 NER = 'ner'
 SENTIMENT = 'sentiment'
+CONSTITUENCY = 'constituency'
