@@ -25,11 +25,16 @@ def get_default_paths():
 
         # TODO: not sure what other people actually have
         # TODO: also, could make this automatically update to the latest
-        "UDBASE": "extern_data/ud2/ud-treebanks-v2.7",
+        "UDBASE": "extern_data/ud2/ud-treebanks-v2.8",
 
         "NERBASE": "extern_data/ner",
 
-        "EXTERN_DIR": "extern_data",
+        # there's a stanford github, stanfordnlp/handparsed-treebank,
+        # with some data for different languages
+        "HANDPARSED_DIR": "extern_data/handparsed-treebank",
+
+        # data root for other general input files, such as VI_VLSP
+        "EXTERN_DIR": "extern_data"
     }
 
     paths = { "DATA_ROOT" : DATA_ROOT }
